@@ -22,3 +22,11 @@ class DummyNotionOAuthResponseFactory(NotionOAuthResponseFactory):
 
     async def make_auth_response(self, token_info: TokenResponseInfo) -> Response:
         return Response(text='OK', status=HTTPStatus.OK)
+
+
+class EchoNotionOAuthResponseFactory(NotionOAuthResponseFactory):
+    async def make_error_response(self, error: str) -> Response:
+        return Response(text=f'Error: {error}', status=HTTPStatus.FORBIDDEN)
+
+    async def make_auth_response(self, token_info: TokenResponseInfo) -> Response:
+        return Response(text=f'Token info: {token_info}', status=HTTPStatus.OK)
